@@ -139,7 +139,7 @@ def validate_otherSites_cycleDuration(cycle: dict):
     }
 
 
-def validate_cycle(cycle: dict, nodes=[]):
+def validate_cycle(cycle: dict, node_map: dict = {}):
     """
     Validates a single `Cycle`.
 
@@ -147,20 +147,20 @@ def validate_cycle(cycle: dict, nodes=[]):
     ----------
     cycle : dict
         The `Cycle` to validate.
-    nodes : list
-        The list of all nodes to do cross-validation.
+    node_map : dict
+        The list of all nodes to do cross-validation, grouped by `type` and `id`.
 
     Returns
     -------
     List
         The list of errors for the `Cycle`, which can be empty if no errors detected.
     """
-    site = _find_linked_node(nodes, cycle.get('site', {}))
+    site = _find_linked_node(node_map, cycle.get('site', {}))
     return flatten([
         validate_cycle_dates(cycle),
         validate_date_lt_today(cycle, 'startDate'),
         validate_date_lt_today(cycle, 'endDate'),
-        validate_linked_source_privacy(cycle, 'defaultSource', nodes),
+        validate_linked_source_privacy(cycle, 'defaultSource', node_map),
         validate_cycleDuration(cycle) if _should_validate_cycleDuration(cycle) else True,
         validate_dataCompleteness(cycle.get('dataCompleteness', {}), site) if 'dataCompleteness' in cycle else True,
         validate_siteDuration(cycle),
