@@ -7,7 +7,7 @@ from .shared import (
 )
 
 
-def validate_impact_assessment(impact_assessment: dict, nodes=[]):
+def validate_impact_assessment(impact_assessment: dict, node_map: dict = {}):
     """
     Validates a single `ImpactAssessment`.
 
@@ -15,8 +15,8 @@ def validate_impact_assessment(impact_assessment: dict, nodes=[]):
     ----------
     impact_assessment : dict
         The `ImpactAssessment` to validate.
-    nodes : list
-        The list of all nodes to do cross-validation.
+    node_map : dict
+        The list of all nodes to do cross-validation, grouped by `type` and `id`.
 
     Returns
     -------
@@ -26,7 +26,7 @@ def validate_impact_assessment(impact_assessment: dict, nodes=[]):
     return [
         validate_date_lt_today(impact_assessment, 'startDate'),
         validate_date_lt_today(impact_assessment, 'endDate'),
-        validate_linked_source_privacy(impact_assessment, 'source', nodes),
+        validate_linked_source_privacy(impact_assessment, 'source', node_map),
         validate_country(impact_assessment) if 'country' in impact_assessment else True,
         validate_is_region(impact_assessment) if 'region' in impact_assessment else True,
         validate_region_in_country(impact_assessment) if 'region' in impact_assessment else True
