@@ -135,3 +135,28 @@ def validate_term_unique(measurements: list):
         }
 
     return _filter_list_errors(map(validate, enumerate(measurements)))
+
+
+def validate_require_startDate_endDate(measurements: list):
+    lookup = download_lookup('measurement.csv', True)
+
+    def validate(values: tuple):
+        index, measurement = values
+        term_id = measurement.get('term', {}).get('@id')
+        start_date = measurement.get('startDate')
+        end_date = measurement.get('endDate')
+        required = get_table_value(lookup, 'termid', term_id, column_name('needStartDateEndDate'))
+        return not required or (start_date is not None and end_date is not None) or [
+            {
+                'level': 'error',
+                'dataPath': f".measurements[{index}].startDate",
+                'message': 'is required'
+            },
+            {
+                'level': 'error',
+                'dataPath': f".measurements[{index}].endDate",
+                'message': 'is required'
+            }
+        ]
+
+    return _filter_list_errors(flatten(map(validate, enumerate(measurements))))
