@@ -12,7 +12,7 @@ def validate_organisation_dates(organisation: dict):
     }
 
 
-def validate_organisation(organisation: dict, nodes=[]):
+def validate_organisation(organisation: dict, node_map: dict = {}):
     """
     Validates a single `Organisation`.
 
@@ -20,8 +20,8 @@ def validate_organisation(organisation: dict, nodes=[]):
     ----------
     organisation : dict
         The `Organisation` to validate.
-    nodes : list
-        The list of all nodes to do cross-validation.
+    node_map : dict
+        The list of all nodes to do cross-validation, grouped by `type` and `id`.
 
     Returns
     -------
