@@ -10,7 +10,7 @@ def test_validate_economicValueShare_valid():
 
     with open(f"{fixtures_path}/product/economicValueShare/valid.json") as f:
         data = json.load(f)
-    assert validate_economicValueShare(data.get('nodes'))
+    assert validate_economicValueShare(data.get('nodes')) is True
 
 
 def test_validate_economicValueShare_invalid():
@@ -32,7 +32,7 @@ def test_validate_value_valid():
 
     with open(f"{fixtures_path}/product/value/valid.json") as f:
         data = json.load(f)
-    assert validate_value(data.get('nodes'))
+    assert validate_value(data.get('nodes')) is True
 
 
 def test_validate_value_warning():
