@@ -1,6 +1,7 @@
 import json
 
 from tests.utils import fixtures_path
+from hestia_earth.validation.utils import _group_nodes, _hash_nodes
 from hestia_earth.validation.validators.shared import (
     validate_dates, validate_list_dates, validate_list_duplicates, validate_list_min_max,
     validate_country, validate_region_in_country, validate_is_region, validate_area, validate_coordinates,
@@ -52,7 +53,11 @@ def test_validate_list_dates_length_invalid():
     assert validate_list_dates_length(cycle, 'emissions') == {
         'level': 'error',
         'dataPath': '.emissions[0].dates',
-        'message': 'must contain 1 value'
+        'message': 'must contain as many items as values',
+        'params': {
+            'current': 2,
+            'expected': 1
+        }
     }
 
 
@@ -379,18 +384,18 @@ def test_validate_linked_source_privacy_valid():
         'dataPrivate': True
     }
     # valid if no connected source
-    assert validate_linked_source_privacy(node, 'source', []) is True
+    assert validate_linked_source_privacy(node, 'source', {}) is True
 
     source = {
         'type': 'Source',
         'id': '1',
         'dataPrivate': True
     }
-    assert validate_linked_source_privacy(node, 'source', [source]) is True
+    assert validate_linked_source_privacy(node, 'source', _group_nodes([source])) is True
 
     node['dataPrivate'] = False
     source['dataPrivate'] = False
-    assert validate_linked_source_privacy(node, 'source', [source]) is True
+    assert validate_linked_source_privacy(node, 'source', _group_nodes([source])) is True
 
 
 def test_validate_linked_source_privacy_invalid():
@@ -406,7 +411,7 @@ def test_validate_linked_source_privacy_invalid():
         'id': '1',
         'dataPrivate': True
     }
-    assert validate_linked_source_privacy(node, 'source', [source]) == {
+    assert validate_linked_source_privacy(node, 'source', _group_nodes([source])) == {
         'level': 'error',
         'dataPath': '.dataPrivate',
         'message': 'should have the same privacy as the related source',
@@ -420,7 +425,7 @@ def test_validate_linked_source_privacy_invalid():
 
     node['dataPrivate'] = True
     source['dataPrivate'] = False
-    assert validate_linked_source_privacy(node, 'source', [source]) == {
+    assert validate_linked_source_privacy(node, 'source', _group_nodes([source])) == {
         'level': 'error',
         'dataPath': '.dataPrivate',
         'message': 'should have the same privacy as the related source',
@@ -685,13 +690,13 @@ def test_validate_list_duplicate_values_invalid():
 def test_validate_nodes_duplicates_valid():
     with open(f"{fixtures_path}/shared/data-duplicates/valid.json") as f:
         nodes = json.load(f)
-    assert validate_nodes_duplicates(nodes[0], nodes) == []
+    assert validate_nodes_duplicates(nodes[0], _hash_nodes(nodes)) == []
 
 
 def test_validate_nodes_duplicates_invalid():
     with open(f"{fixtures_path}/shared/data-duplicates/warning.json") as f:
         nodes = json.load(f)
-    assert validate_nodes_duplicates(nodes[0], nodes) == [{
+    assert validate_nodes_duplicates(nodes[0], _hash_nodes(nodes)) == [{
         'level': 'warning',
         'dataPath': '',
         'message': 'might be a duplicate of the Site with id 2'
